@@ -1,20 +1,16 @@
 # © Copyright Databand.ai, an IBM Company 2022
+import datetime
 
 from typing import Optional
 
 import attr
 
-from airflow_monitor.shared.base_monitor_config import BaseMonitorConfig
+from airflow_monitor.shared.base_monitor_config import (
+    NOTHING,
+    BaseMonitorConfig,
+    BaseMonitorState,
+)
 from airflow_monitor.shared.base_server_monitor_config import BaseServerConfig
-from dbnd._core.tracking.schemas.base import ApiStrictSchema
-from dbnd._core.utils.basics.nothing import NOTHING
-from dbnd._vendor.marshmallow import fields
-
-
-class DbtUpdateMonitorStateRequestSchema(ApiStrictSchema):
-    monitor_status = fields.String(required=False, allow_none=True)
-    monitor_error_message = fields.String(required=False, allow_none=True)
-    last_sync_time = fields.DateTime(required=False, allow_none=True)
 
 
 @attr.s
@@ -46,18 +42,18 @@ class DbtServerConfig(BaseServerConfig):
         return conf
 
 
-@attr.s
-class DbtMonitorState:
-    monitor_status = attr.ib(default=NOTHING)
-    monitor_error_message = attr.ib(default=NOTHING)
-    last_sync_time = attr.ib(default=NOTHING)
+@attr.s(auto_attribs=True)
+class DbtMonitorState(BaseMonitorState):
+    monitor_status: str = NOTHING
+    monitor_error_message: Optional[str] = NOTHING
+    last_sync_time: Optional[datetime.datetime] = NOTHING
 
-    def as_dict(self):
-        # Return only non NOTHING values (that did not change), None values are OK
-        return attr.asdict(
-            self, filter=lambda attr_name, attr_value: attr_value != NOTHING
-        )
+    def as_dict(self) -> dict:
+        data = super().as_dict()
+        if data.get("last_sync_time"):
+            data["last_sync_time"] = self.last_sync_time.isoformat()
+        return data
 
 
 class DbtMonitorConfig(BaseMonitorConfig):
-    _conf__task_family = "dbt_monitor"
+    _env_prefix = "DBND__DBT_MONITOR__"
